@@ -39,7 +39,8 @@ import uuid
 
 from functools import partial
 from itertools import chain
-from oauth import oauth
+from urlparse import urlparse, parse_qsl
+from oauthlib.oauth1 import Client, SIGNATURE_PLAINTEXT, SIGNATURE_TYPE_QUERY
 
 from twisted.internet.protocol import ClientFactory
 from twisted.internet import reactor, defer
@@ -143,29 +144,30 @@ class StorageClient(request.RequestHandler):
     def oauth_authenticate(self, consumer, token, metadata=None):
         """Authenticate to a server using the OAuth provider.
 
-        @param consumer: the OAuth consumer to authenticate with.
-        @type consumer: `oauth.OAuthConsumer`
-        @param token: a previously acquired OAuth access token.
-        @type consumer: `oauth.OAuthToken`
-        @param kwargs: key/values to send as metadata
+        @param consumer: the OAuth consumer (a.k.a. client in RFC 5849) to
+            authenticate with.
+        @type consumer: object having both a `.key` and `.secret` attribute.
+        @param token: a previously acquired OAuth access token (a.k.a.
+            resource owner in RFC 5849).
+        @type token: object having both a `.key` and `.secret` attribute.
+        @param metadata: key/values to send as metadata
 
         Return a deferred that will get called with the request
         object when completed.
 
         """
         timestamp = yield tx_timestamp_checker.get_faithful_time()
-        req = oauth.OAuthRequest.from_consumer_and_token(
-            oauth_consumer=consumer,
-            token=token,
-            parameters={"oauth_timestamp": timestamp},
-            http_method="GET",
-            http_url="storage://server")
-        req.sign_request(
-            oauth.OAuthSignatureMethod_PLAINTEXT(), consumer, token)
-
-        # Make sure all parameter values are strings.
+        client = Client(consumer.key, consumer.secret,
+                        token.key, token.secret,
+                        signature_method=SIGNATURE_PLAINTEXT,
+                        signature_type=SIGNATURE_TYPE_QUERY,
+                        timestamp=timestamp)
+        url, headers, body = client.sign('storage://server')
+        # Parse out the authentication parameters from the query string.
         auth_parameters = dict(
-            (key, str(value)) for key, value in req.parameters.iteritems())
+            (name, value) for name, value in
+            parse_qsl(urlparse(url).query)
+            if name.startswith('oauth_'))
         p = Authenticate(self, auth_parameters, metadata=metadata)
         p.start()
         result = yield p.deferred
@@ -882,8 +884,8 @@ class CreateUDF(request.Request):
 
     def processMessage(self, message):
         """Process the answer from the server."""
-        if (message.type == protocol_pb2.Message.VOLUME_CREATED and
-            message.volume_created.type == protocol_pb2.Volumes.UDF):
+        if message.type == protocol_pb2.Message.VOLUME_CREATED and \
+                message.volume_created.type == protocol_pb2.Volumes.UDF:
             self.volume_id = message.volume_created.udf.volume
             self.node_id = message.volume_created.udf.node
             self.done()
